@@ -28,7 +28,7 @@
 #include "kgpgsettings.h"
 #include "model/kgpgitemmodel.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 KGpgKeyNode::KGpgKeyNode(KGpgRootNode *parent, const KgpgCore::KgpgKey &k)
 	: KGpgSignableNode(parent),
@@ -39,8 +39,10 @@ KGpgKeyNode::KGpgKeyNode(KGpgRootNode *parent, const KgpgCore::KgpgKey &k)
 
 KGpgKeyNode::~KGpgKeyNode()
 {
+	// do not try to access the root node if we are being deleted from there
+	KGpgRootNode * const root = parent() != Q_NULLPTR ? m_parent->toRootNode() : Q_NULLPTR;
 	foreach (KGpgRefNode *nd, m_refs) {
-		nd->unRef(m_parent->toRootNode());
+		nd->unRef(root);
 	}
 }
 
@@ -81,8 +83,8 @@ QString
 KGpgKeyNode::getSize() const
 {
 	return i18nc("size of signing key / size of encryption key",
-			"%1 / %2", QString::number(getSignKeySize()),
-			QString::number(getEncryptionKeySize()));
+			"%1 / %2", m_key->strength(),
+			m_key->encryptionStrength());
 }
 
 QString
